==> wiki3_4_0.zip: wiki3_4_0/plugin/admin/Login.pm <==
###############################################################################
#
# ԥ
#
###############################################################################
package plugin::admin::Login;

#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# ϥɥ
#==============================================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	
	$wiki->set_title("");
	my $cgi = $wiki->get_CGI;
	
	if($cgi->param("logout") ne ""){
		return $self->logout($wiki);
	}
	
	if(defined($wiki->get_login_info($cgi))){
		return $self->admin_form($wiki,$wiki->get_login_info($cgi));
	} else {
		# Ƚ
		my $id   = $cgi->param("id");
		my $pass = $cgi->param("pass");
		if($id ne "" && $pass ne ""){
			my $login = $wiki->login_check($id,$pass);
			if(defined($login)){
				my $cookie = $cgi->cookie(-name=>wiki_id,-value=>$id);
				print "Set-Cookie: ",$cookie->as_string,"\n";
				return $self->admin_form($wiki,$login);
			} else {
				return $wiki->error("ID⤷ϥѥɤ㤤ޤ");
			}
		}
	}
	return $self->default;
}

#==============================================================================
# ̥ե
#==============================================================================
sub admin_form {
	my $self  = shift;
	my $wiki  = shift;
	my $login = shift;
	my $buf = "<h2></h2>\n";
	if($login->{type}==0){
		$buf .="<ul>\n";
		foreach($wiki->get_admin_menu){
			$buf .= "<li><a href=\"".$_->{url}."\">".$_->{label}."</a></li>\n";
		}
		$buf .= "</ul>\n";
	}
	$buf .= "<form action=\"$main::script_name\" method=\"POST\">".
	        "  <input type=\"submit\" name=\"logout\" value=\"\">".
	        "  <input type=\"hidden\" name=\"action\" value=\"LOGIN\">".
	        "</form>\n";
	        
	return $buf;
}

#==============================================================================
# Ƚ
#==============================================================================
sub logout {
	my $self = shift;
	my $wiki = shift;
	my $cgi = $wiki->get_CGI;
	
	my $cookie = $cgi->cookie(-name=>wiki_id,-value=>'');
	print "Set-Cookie: ",$cookie->as_string,"\n";
	return "Ȥޤ";
}

#==============================================================================
# 
#==============================================================================
sub default {
	my $self = shift;
	my $wiki = shift;
	return "<h2>IDȥѥɤϤƤ</h2>\n".
	       "<form action=\"$main::script_name\" method=\"POST\">".
	       "  <table>\n".
	       "    <tr><th>ID  </th><td><input type=\"text\" name=\"id\"></td></tr>\n".
	       "    <tr><th>Pass</th><td><input type=\"password\" name=\"pass\"></td></tr>\n".
	       "  </table><br>\n".
	       "  <input type=\"submit\" name=\"login\" value=\"\">\n".
	       "  <input type=\"hidden\" name=\"action\" value=\"LOGIN\">\n".
	       "</form>\n";
}

1;

==> wiki3_4_1.zip: wiki3_4_1/plugin/admin/Login.pm <==
###############################################################################
#
# ԥ
#
###############################################################################
package plugin::admin::Login;
use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self  = {};
	return bless $self,$class;
}

#==============================================================================
# ϥɥ
#==============================================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	
	$wiki->set_title("");
	my $cgi = $wiki->get_CGI;
	
	if($cgi->param("logout") ne ""){
		return $self->logout($wiki);
	}
	
	if(defined($wiki->get_login_info($cgi))){
		return $self->admin_form($wiki,$wiki->get_login_info($cgi));
	} else {
		# Ƚ
		my $id   = $cgi->param("id");
		my $pass = $cgi->param("pass");
		if($id ne "" && $pass ne ""){
			my $login = $wiki->login_check($id,crypt($pass,$id));
			if(defined($login)){
				my $cookie = $cgi->cookie(-name=>'wiki_id',-value=>$id);
				print "Set-Cookie: ",$cookie->as_string,"\n";
				return $self->admin_form($wiki,$login);
			} else {
				return $wiki->error("ID⤷ϥѥɤ㤤ޤ");
			}
		}
	}
	return $self->default($wiki);
}

#==============================================================================
# ̥ե
#==============================================================================
sub admin_form {
	my $self  = shift;
	my $wiki  = shift;
	my $login = shift;
	my $buf = "<h2></h2>\n";
	
	if($login->{type}==0){
		$buf .="<ul>\n";
		foreach($wiki->get_admin_menu){
			$buf .= "<li><a href=\"".$_->{url}."\">".$_->{label}."</a></li>\n";
		}
		$buf .= "</ul>\n";
	}
	
	$buf .= "<form action=\"".$wiki->config('script_name')."\" method=\"POST\">".
	        "  <input type=\"submit\" name=\"logout\" value=\"\">".
	        "  <input type=\"hidden\" name=\"action\" value=\"LOGIN\">".
	        "</form>\n";
	
	return $buf;
}

#==============================================================================
# Ƚ
#==============================================================================
sub logout {
	my $self = shift;
	my $wiki = shift;
	my $cgi = $wiki->get_CGI;
	
	my $cookie = $cgi->cookie(-name=>'wiki_id',-value=>'');
	print "Set-Cookie: ",$cookie->as_string,"\n";
	return "Ȥޤ";
}

#==============================================================================
# 
#==============================================================================
sub default {
	my $self = shift;
	my $wiki = shift;
	return "<h2>IDȥѥɤϤƤ</h2>\n".
	       "<form action=\"".$wiki->config('script_name')."\" method=\"POST\">".
	       "  <table>\n".
	       "    <tr><th>ID  </th><td><input type=\"text\" name=\"id\"></td></tr>\n".
	       "    <tr><th>Pass</th><td><input type=\"password\" name=\"pass\"></td></tr>\n".
	       "  </table><br>\n".
	       "  <input type=\"submit\" name=\"login\" value=\"\">\n".
	       "  <input type=\"hidden\" name=\"action\" value=\"LOGIN\">\n".
	       "</form>\n";
}

1;
